"Suds" is a lightweight SOAP-based web service client for Python licensed under
LGPL (see the ``LICENSE.txt`` file included in the distribution).

Based on the original `suds <https://pypi.org/project/suds>`_
and `suds-jurko <https://pypi.org/project/suds-jurko>`_ projects.

For development notes see the ``HACKING.rst`` document included in the
distribution.
